==> gen_export-1.1.4.tar.gz: lib/src/gen_translation.dart <==
import 'dart:collection';
import 'dart:convert';
import 'dart:io';

import 'package:translator/translator.dart';
import 'package:yaml/yaml.dart';

void genTranslation() async {
  final pubspecYaml = File('pubspec.yaml');
  if (!pubspecYaml.existsSync()) {
    throw Exception('No pubspec.yaml exists in your current directory');
  }

  final pubspec = loadYaml(pubspecYaml.readAsStringSync());
  final YamlList languages = pubspec['languages'] ?? ['en', 'id'];

  final l10nYaml = File('l10n.yaml');
  if (!l10nYaml.existsSync()) {
    throw Exception('No l10n.yaml exists in your project');
  }

  final translator = GoogleTranslator();

  final config = loadYaml(l10nYaml.readAsStringSync());
  final String arbDir = config['arb-dir'] ?? 'lib/l10n';
  final String templateArbFile = config['template-arb-file'] ?? 'app_en.arb';
  var templateName =
      templateArbFile.substring(0, templateArbFile.lastIndexOf('_'));

  var defaultLang = templateArbFile.replaceAll('.arb', '');
  defaultLang = defaultLang.substring(defaultLang.lastIndexOf('_') + 1);

  final defaultArb = File('$arbDir/$templateArbFile');
  final defaultArbData =
      json.decode(defaultArb.readAsStringSync()) as Map<String, dynamic>;

  final encoder = JsonEncoder.withIndent('    ');

  for (String lang in languages.where((element) => element != defaultLang)) {
    var countryLang = lang;
    if (lang.contains(RegExp(r'[\-_]'))) {
      countryLang = lang.substring(0, lang.indexOf(RegExp(r'[\-_]')));
    }

    final newArb =
        File('$arbDir/${templateName}_${countryLang.toLowerCase()}.arb');
    var arbData = <String, dynamic>{};
    if (newArb.existsSync()) {
      arbData = json.decode(newArb.readAsStringSync());
    }

    for (var key in defaultArbData.keys) {
      if (arbData.containsKey(key)) continue;

      final String source = defaultArbData[key];
      if (source.trim().isEmpty) {
        arbData[key] = source;
        continue;
      }

      final translation = await translator.translate(
        source,
        from: defaultLang,
        to: lang.toLowerCase().replaceAll('_', '-'),
      );

      arbData[key] = translation.text;
    }

    var sorted = SplayTreeMap.from(arbData);
    newArb.writeAsStringSync(encoder.convert(sorted), flush: true);
  }

  await Process.run('flutter', ['gen-l10n']);
}

==> gen_export-1.1.5.tar.gz: lib/src/gen_translation.dart <==
import 'dart:collection';
import 'dart:convert';
import 'dart:io';

import 'package:translator/translator.dart';
import 'package:yaml/yaml.dart';

void genTranslation() async {
  final pubspecYaml = File('pubspec.yaml');
  if (!pubspecYaml.existsSync()) {
    throw Exception('No pubspec.yaml exists in your current directory');
  }

  final pubspec = loadYaml(pubspecYaml.readAsStringSync());
  final YamlList languages = pubspec['languages'] ?? ['en', 'id'];

  final l10nYaml = File('l10n.yaml');
  if (!l10nYaml.existsSync()) {
    throw Exception('No l10n.yaml exists in your project');
  }

  final translator = GoogleTranslator();

  final config = loadYaml(l10nYaml.readAsStringSync());
  final String arbDir = config['arb-dir'] ?? 'lib/l10n';
  final String templateArbFile = config['template-arb-file'] ?? 'app_en.arb';
  var templateName =
      templateArbFile.substring(0, templateArbFile.lastIndexOf('_'));

  var defaultLang = templateArbFile.replaceAll('.arb', '');
  defaultLang = defaultLang.substring(defaultLang.lastIndexOf('_') + 1);

  final defaultArb = File('$arbDir/$templateArbFile');
  final defaultArbData =
      json.decode(defaultArb.readAsStringSync()) as Map<String, dynamic>;

  final encoder = JsonEncoder.withIndent('    ');

  for (String lang in languages.where((element) => element != defaultLang)) {
    var countryLang = lang;
    if (lang.contains(RegExp(r'[\-_]'))) {
      countryLang = lang.substring(0, lang.indexOf(RegExp(r'[\-_]')));
    }

    final newArb =
        File('$arbDir/${templateName}_${countryLang.toLowerCase()}.arb');
    var arbData = <String, dynamic>{};
    if (newArb.existsSync()) {
      arbData = json.decode(newArb.readAsStringSync());
    }

    for (var key in defaultArbData.keys) {
      if (arbData.containsKey(key)) continue;

      final value = defaultArbData[key];
      if (value! is String) {
        print("Cannot translate $key, because it's not string");
        continue;
      }

      final String source = value;
      if (source.trim().isEmpty) {
        arbData[key] = source;
        continue;
      }

      final translation = await translator.translate(
        source,
        from: defaultLang,
        to: lang.toLowerCase().replaceAll('_', '-'),
      );

      arbData[key] = translation.text;
    }

    var sorted = SplayTreeMap.from(arbData);
    newArb.writeAsStringSync(encoder.convert(sorted), flush: true);
  }

  await Process.run('flutter', ['gen-l10n']);
}
